Dashboard - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

Overview

## Navbar overlap layout

New view
Create new report
Sales
Last 7 days
75%
Conversion rate
7%
75% Complete
Revenue
Last 7 days
$4,300
8%
New clients
Last 7 days
6,782
0%
Active users
Last 7 days
2,986
4%
132 Sales
12 waiting payments
78 Orders
32 shipped
623 Shares
16 today
132 Likes
21 today

### Traffic summary

### Locations

Using Storage 6854.45 MB of 8 GB

Regular 915MB
System 415MB
Shared 201MB
Free 612MB
JL
Jeffie Lewzey commented on your "I'm not a witch." post.
yesterday
It's Mallory Hulme's birthday. Wish him well!
2 days ago
Dunn Slane posted "Well, what do you want?".
today
Emmy Levet created a new project Morning alarm clock.
4 days ago
Maryjo Lebarree liked your photo.
2 days ago
EP
Egan Poetz registered new client as Trilia.
yesterday
Kellie Skingley closed a new deal on project Pen Pineapple Apple Pen.
2 days ago
Christabel Charlwood created a new project for Wikibox.
4 days ago
HS
Haskel Shelper change status of Tabler Icons from open to closed.
today
Lorry Mion liked Tabler UI Kit.
yesterday
Leesa Beaty posted new video.
2 days ago
Perren Keemar and 3 others followed you.
2 days ago
SA
Sunny Airey upload 3 new photos to category Inspirations.
2 days ago
Geoffry Flaunders made a $10 donation.
2 days ago
Thatcher Keel created a profile.
3 days ago
Dyann Escala hosted the event Tabler UI Birthday.
4 days ago
Avivah Mugleston mentioned you on Best of 2020.
2 days ago
AA
Arlie Armstead sent a Review Request to Amanda Blake.
2 days ago
Development activity
Today's Earning: $4,262.40
+5% more than yesterday

User | Commit | Date
--- | --- | ---
| Fix dart Sass compatibility (#29755) | 28 Nov 2019
JL | Change deprecated html tags to text decoration classes (#29604) | 27 Nov 2019
| justify-content:between ⇒ justify-content:space-between (#29734) | 26 Nov 2019
| Update change-version.js (#29736) | 26 Nov 2019
| Regenerate package-lock.json (#29730) | 25 Nov 2019
| Some minor text tweaks | 24 Nov 2019

### Tabler Icons

All icons come from the Tabler Icons set and are MIT-licensed. Visit tabler-icons.io, download any of the 1518 icons in SVG, PNG or React and use them in your favourite design tools.
Download icons

### Most Visited Pages

Page name | Visitors | Unique | Bounce rate
--- | --- | --- | ---
/about.html | 4,896 | 3,654 | 82.54% |
/special-promo.html | 3,652 | 3,215 | 76.29% |
/news/1,new-ui-kit.html | 3,256 | 2,865 | 72.65% |
/lorem-ipsum-dolor-sit-amet-very-long-url.html | 986 | 865 | 44.89% |
/colors.html | 912 | 822 | 41.12% |
/docs/index.html | 855 | 798 | 32.65% |

### Social Media Traffic

Network | Visitors
--- | ---
Instagram | 3,550 |
Twitter | 1,798 |
Facebook | 1,245 |
TikTok | 986 |
Pinterest | 854 |
VK | 650 |
Pinterest | 420 |

### Tasks

| Extend the data model. | January 01, 2019 | 2/7 | 3 |
| Verify the event flow. | January 01, 2019 | 3/10 | 6 | JL
| Database backup and maintenance | January 01, 2019 | 0/6 | 1 |
| Identify the implementation team. | January 01, 2019 | 6/10 | 12 |
| Define users and workflow | January 01, 2019 | 3/7 | 5 |
| Check Pull Requests | January 01, 2019 | 2/9 | 3 |

### Invoices

Show
entries
Search:

| No. | Invoice Subject | Client | VAT No. | Created | Status | Price |
--- | --- | --- | --- | --- | --- | --- | --- | ---
| 001401 | Design Works | Carlson Limited | 87956621 | 15 Dec 2017 | Paid | $887 |
| 001402 | UX Wireframes | Adobe | 87956421 | 12 Apr 2017 | Pending | $1200 |
| 001403 | New Dashboard | Bluewolf | 87952621 | 23 Oct 2017 | Pending | $534 |
| 001404 | Landing Page | Salesforce | 87953421 | 2 Sep 2017 | Due in 2 Weeks | $1500 |
| 001405 | Marketing Templates | Printic | 87956621 | 29 Jan 2018 | Paid Today | $648 |
| 001406 | Sales Presentation | Tabdaq | 87956621 | 4 Feb 2018 | Due in 3 Weeks | $300 |
| 001407 | Logo & Print | Apple | 87956621 | 22 Mar 2018 | Paid Today | $2500 |
| 001408 | Icons | Tookapic | 87956621 | 13 May 2018 | Paid Today | $940 |

##### New report

Name
Report type
Simple Provide only basic data needed for the report
Advanced Insert charts and additional advanced analyses to be inserted in the report
Report url
https://tabler.io/reports/
Visibility
Client name
Reporting period
Additional information